@@ -32,6 +32,7 @@
 #include <math.h>
 
 #include "application.h"
+#include "stylable.h"
 
 #if GTK_CHECK_VERSION(3, 14 ,0)
 #undef USE_GTK_BUILTIN_ICONS
@@ -40,9 +41,12 @@
 #endif
 
 /* Define this class in GObject system */
-G_DEFINE_TYPE(XfdashboardImageContent,
-				xfdashboard_image_content,
-				CLUTTER_TYPE_IMAGE)
+static void _xfdashboard_image_content_stylable_iface_init(XfdashboardStylableInterface *iface);
+
+G_DEFINE_TYPE_WITH_CODE(XfdashboardImageContent,
+						xfdashboard_image_content,
+						CLUTTER_TYPE_IMAGE,
+						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_STYLABLE, _xfdashboard_image_content_stylable_iface_init))
 
 /* Local definitions */
 typedef enum /*< skip,prefix=XFDASHBOARD_IMAGE_TYPE >*/
@@ -60,19 +64,19 @@ typedef enum /*< skip,prefix=XFDASHBOARD_IMAGE_TYPE >*/
 struct _XfdashboardImageContentPrivate
 {
 	/* Properties related */
-	gchar					*key;
+	gchar								*key;
+	gchar								*missingIconName;
 
 	/* Instance related */
-	XfdashboardImageType	type;
-	gboolean				isLoaded;
-	gboolean				successfulLoaded;
-	GtkIconTheme			*iconTheme;
-	gchar					*iconName;
-	GIcon					*gicon;
-	gint					iconSize;
+	XfdashboardImageType				type;
+	XfdashboardImageContentLoadingState	loadState;
+	GtkIconTheme						*iconTheme;
+	gchar								*iconName;
+	GIcon								*gicon;
+	gint								iconSize;
 
-	guint					contentAttachedSignalID;
-	guint					iconThemeChangedSignalID;
+	guint								contentAttachedSignalID;
+	guint								iconThemeChangedSignalID;
 };
 
 /* Properties */
@@ -81,6 +85,11 @@ enum
 	PROP_0,
 
 	PROP_KEY,
+	PROP_MISSING_ICON_NAME,
+
+	/* From interface: XfdashboardStylable */
+	PROP_STYLE_CLASSES,
+	PROP_STYLE_PSEUDO_CLASSES,
 
 	PROP_LAST
 };
@@ -102,7 +111,7 @@ static guint XfdashboardImageContentSignals[SIGNAL_LAST]={ 0, };
 static GHashTable*	_xfdashboard_image_content_cache=NULL;
 static guint		_xfdashboard_image_content_cache_shutdownSignalID=0;
 
-#define XFDASHBOARD_IMAGE_CONTENT_FALLBACK_ICON_NAME		"gtk-missing-image"
+#define XFDASHBOARD_IMAGE_CONTENT_DEFAULT_FALLBACK_ICON_NAME		"image-missing"
 
 /* Get image from cache if available */
 static ClutterImage* _xfdashboard_image_content_get_cached_image(const gchar *inKey)
@@ -252,7 +261,7 @@ static void _xfdashboard_image_content_loading_async_callback(GObject *inSource,
 	GdkPixbuf							*pixbuf;
 	GError								*error=NULL;
 
-	priv->successfulLoaded=TRUE;
+	priv->loadState=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_SUCCESSFULLY;
 
 	/* Get pixbuf loaded */
 	pixbuf=gdk_pixbuf_new_from_stream_finish(inResult, &error);
@@ -278,7 +287,7 @@ static void _xfdashboard_image_content_loading_async_callback(GObject *inSource,
 
 			/* Set failed state and empty image */
 			_xfdashboard_image_content_set_empty_image(self);
-			priv->successfulLoaded=FALSE;
+			priv->loadState=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_FAILED;
 		}
 	}
 		else
@@ -294,14 +303,14 @@ static void _xfdashboard_image_content_loading_async_callback(GObject *inSource,
 
 			/* Set failed state and empty image */
 			_xfdashboard_image_content_set_empty_image(self);
-			priv->successfulLoaded=FALSE;
+			priv->loadState=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_FAILED;
 		}
 
 	/* Release allocated resources */
 	if(pixbuf) g_object_unref(pixbuf);
 
 	/* Emit "loaded" signal if loading was successful ... */
-	if(priv->successfulLoaded)
+	if(priv->loadState==XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_SUCCESSFULLY)
 	{
 		g_signal_emit(self, XfdashboardImageContentSignals[SIGNAL_LOADED], 0);
 		g_debug("Successfully loaded image for key '%s' asynchronously", priv->key ? priv->key : "<nil>");
@@ -365,7 +374,7 @@ static void _xfdashboard_image_content_load_from_file(XfdashboardImageContent *s
 		g_warning(_("Icon file '%s' does not exist - trying fallback icon"), priv->iconName);
 
 		iconInfo=gtk_icon_theme_lookup_icon(priv->iconTheme,
-											XFDASHBOARD_IMAGE_CONTENT_FALLBACK_ICON_NAME,
+											priv->missingIconName,
 											priv->iconSize,
 #ifdef USE_GTK_BUILTIN_ICONS
 											GTK_ICON_LOOKUP_USE_BUILTIN);
@@ -607,7 +616,7 @@ static void _xfdashboard_image_content_load_from_icon_name(XfdashboardImageConte
 		g_warning(_("Could not lookup themed icon '%s'"), priv->iconName);
 
 		iconInfo=gtk_icon_theme_lookup_icon(priv->iconTheme,
-											XFDASHBOARD_IMAGE_CONTENT_FALLBACK_ICON_NAME,
+											priv->missingIconName,
 											priv->iconSize,
 											GTK_ICON_LOOKUP_USE_BUILTIN);
 	}
@@ -615,7 +624,7 @@ static void _xfdashboard_image_content_load_from_icon_name(XfdashboardImageConte
 	/* If we still got no icon info then we cannot load icon at all */
 	if(!iconInfo)
 	{
-		g_warning(_("Could not lookup fallback icon '%s' for icon '%s'"), XFDASHBOARD_IMAGE_CONTENT_FALLBACK_ICON_NAME, priv->iconName);
+		g_warning(_("Could not lookup fallback icon '%s' for icon '%s'"), priv->missingIconName, priv->iconName);
 		return;
 	}
 
@@ -735,7 +744,7 @@ static void _xfdashboard_image_content_load_from_gicon(XfdashboardImageContent *
 		g_warning(_("Could not lookup gicon '%s'"), g_icon_to_string(priv->gicon));
 
 		iconInfo=gtk_icon_theme_lookup_icon(priv->iconTheme,
-											XFDASHBOARD_IMAGE_CONTENT_FALLBACK_ICON_NAME,
+											priv->missingIconName,
 											priv->iconSize,
 											GTK_ICON_LOOKUP_USE_BUILTIN);
 	}
@@ -841,7 +850,8 @@ static void _xfdashboard_image_content_on_icon_theme_changed(XfdashboardImageCon
 	priv=self->priv;
 
 	/* If icon has not been loaded yet then there is no need to do it now */
-	if(!priv->isLoaded) return;
+	if(priv->loadState!=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_SUCCESSFULLY &&
+		priv->loadState!=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_FAILED) return;
 
 	/* Set empty image - just for the case loading failed at any point */
 	_xfdashboard_image_content_set_empty_image(self);
@@ -953,13 +963,17 @@ static void _xfdashboard_image_content_on_attached(ClutterContent *inContent,
 	self=XFDASHBOARD_IMAGE_CONTENT(inContent);
 	priv=self->priv;
 
+	/* If image is being loaded then do nothing */
+	if(priv->loadState==XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADING) return;
+
 	/* Check if image was already loaded then emit signal
 	 * appropiate for last load status.
 	 */
-	if(priv->isLoaded)
+	if(priv->loadState==XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_SUCCESSFULLY ||
+		priv->loadState==XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_FAILED)
 	{
 		/* Emit "loaded" signal if loading was successful ... */
-		if(priv->successfulLoaded)
+		if(priv->loadState==XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_SUCCESSFULLY)
 		{
 			g_signal_emit(self, XfdashboardImageContentSignals[SIGNAL_LOADED], 0);
 		}
@@ -972,12 +986,15 @@ static void _xfdashboard_image_content_on_attached(ClutterContent *inContent,
 		return;
 	}
 
-	/* Mark image loaded regardless if loading will succeed or fail */
-	priv->isLoaded=TRUE;
+	/* Mark image being loaded */
+	priv->loadState=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADING;
 
 	/* Also disconnect signal handler as it should not be called anymore */
-	g_signal_handler_disconnect(self, priv->contentAttachedSignalID);
-	priv->contentAttachedSignalID=0;
+	if(priv->contentAttachedSignalID)
+	{
+		g_signal_handler_disconnect(self, priv->contentAttachedSignalID);
+		priv->contentAttachedSignalID=0;
+	}
 
 	/* Set empty image - just for the case loading failed at any point */
 	_xfdashboard_image_content_set_empty_image(self);
@@ -1007,6 +1024,54 @@ static void _xfdashboard_image_content_on_attached(ClutterContent *inContent,
 	}
 }
 
+/* IMPLEMENTATION: Interface XfdashboardStylable */
+
+/* Get stylable properties of stage */
+static void _xfdashboard_image_content_stylable_get_stylable_properties(XfdashboardStylable *inStylable,
+																			GHashTable *ioStylableProperties)
+{
+	g_return_if_fail(XFDASHBOARD_IS_STYLABLE(inStylable));
+
+	/* Add stylable properties to hashtable */
+	xfdashboard_stylable_add_stylable_property(inStylable, ioStylableProperties, "missing-icon-name");
+}
+
+/* Get/set style classes of stage */
+static const gchar* _xfdashboard_image_content_stylable_get_classes(XfdashboardStylable *inStylable)
+{
+	/* Not implemented */
+	return(NULL);
+}
+
+static void _xfdashboard_image_content_stylable_set_classes(XfdashboardStylable *inStylable, const gchar *inStyleClasses)
+{
+	/* Not implemented */
+}
+
+/* Get/set style pseudo-classes of stage */
+static const gchar* _xfdashboard_image_content_stylable_get_pseudo_classes(XfdashboardStylable *inStylable)
+{
+	/* Not implemented */
+	return(NULL);
+}
+
+static void _xfdashboard_image_content_stylable_set_pseudo_classes(XfdashboardStylable *inStylable, const gchar *inStylePseudoClasses)
+{
+	/* Not implemented */
+}
+
+/* Interface initialization
+ * Set up default functions
+ */
+void _xfdashboard_image_content_stylable_iface_init(XfdashboardStylableInterface *iface)
+{
+	iface->get_stylable_properties=_xfdashboard_image_content_stylable_get_stylable_properties;
+	iface->get_classes=_xfdashboard_image_content_stylable_get_classes;
+	iface->set_classes=_xfdashboard_image_content_stylable_set_classes;
+	iface->get_pseudo_classes=_xfdashboard_image_content_stylable_get_pseudo_classes;
+	iface->set_pseudo_classes=_xfdashboard_image_content_stylable_set_pseudo_classes;
+}
+
 /* IMPLEMENTATION: GObject */
 
 /* Dispose this object */
@@ -1049,11 +1114,17 @@ static void _xfdashboard_image_content_dispose(GObject *inObject)
 		priv->gicon=NULL;
 	}
 
+	if(priv->missingIconName)
+	{
+		g_free(priv->missingIconName);
+		priv->missingIconName=NULL;
+	}
+
 	/* Call parent's class dispose method */
 	G_OBJECT_CLASS(xfdashboard_image_content_parent_class)->dispose(inObject);
 }
 
-/* Set properties */
+/* Set/get properties */
 static void _xfdashboard_image_content_set_property(GObject *inObject,
 													guint inPropID,
 													const GValue *inValue,
@@ -1067,6 +1138,30 @@ static void _xfdashboard_image_content_set_property(GObject *inObject,
 			_xfdashboard_image_content_store_in_cache(self, g_value_get_string(inValue));
 			break;
 
+		case PROP_MISSING_ICON_NAME:
+			xfdashboard_image_content_set_missing_icon_name(self, g_value_get_string(inValue));
+			break;
+
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID(inObject, inPropID, inSpec);
+			break;
+	}
+}
+
+static void _xfdashboard_image_content_get_property(GObject *inObject,
+													guint inPropID,
+													GValue *outValue,
+													GParamSpec *inSpec)
+{
+	XfdashboardImageContent			*self=XFDASHBOARD_IMAGE_CONTENT(inObject);
+	XfdashboardImageContentPrivate	*priv=self->priv;
+
+	switch(inPropID)
+	{
+		case PROP_MISSING_ICON_NAME:
+			g_value_set_string(outValue, priv->missingIconName);
+			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(inObject, inPropID, inSpec);
 			break;
@@ -1079,11 +1174,16 @@ static void _xfdashboard_image_content_set_property(GObject *inObject,
  */
 void xfdashboard_image_content_class_init(XfdashboardImageContentClass *klass)
 {
-	GObjectClass			*gobjectClass=G_OBJECT_CLASS(klass);
+	GObjectClass					*gobjectClass=G_OBJECT_CLASS(klass);
+	XfdashboardStylableInterface	*stylableIface;
+	GParamSpec						*paramSpec;
 
 	/* Override functions */
 	gobjectClass->dispose=_xfdashboard_image_content_dispose;
 	gobjectClass->set_property=_xfdashboard_image_content_set_property;
+	gobjectClass->get_property=_xfdashboard_image_content_get_property;
+
+	stylableIface=g_type_default_interface_ref(XFDASHBOARD_TYPE_STYLABLE);
 
 	/* Set up private structure */
 	g_type_class_add_private(klass, sizeof(XfdashboardImageContentPrivate));
@@ -1096,6 +1196,21 @@ void xfdashboard_image_content_class_init(XfdashboardImageContentClass *klass)
 							N_(""),
 							G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
 
+	XfdashboardImageContentProperties[PROP_MISSING_ICON_NAME]=
+		g_param_spec_string("missing-icon-name",
+							_("Missing icon name"),
+							_("The icon's name to use when requested image cannot be loaded"),
+							XFDASHBOARD_IMAGE_CONTENT_DEFAULT_FALLBACK_ICON_NAME,
+							G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
+
+	paramSpec=g_object_interface_find_property(stylableIface, "style-classes");
+	XfdashboardImageContentProperties[PROP_STYLE_CLASSES]=
+		g_param_spec_override("style-classes", paramSpec);
+
+	paramSpec=g_object_interface_find_property(stylableIface, "style-pseudo-classes");
+	XfdashboardImageContentProperties[PROP_STYLE_PSEUDO_CLASSES]=
+		g_param_spec_override("style-pseudo-classes", paramSpec);
+
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardImageContentProperties);
 
 	/* Define signals */
@@ -1120,6 +1235,9 @@ void xfdashboard_image_content_class_init(XfdashboardImageContentClass *klass)
 						g_cclosure_marshal_VOID__VOID,
 						G_TYPE_NONE,
 						0);
+
+	/* Release allocated resources */
+	g_type_default_interface_unref(stylableIface);
 }
 
 /* Object initialization
@@ -1137,9 +1255,12 @@ void xfdashboard_image_content_init(XfdashboardImageContent *self)
 	priv->iconName=NULL;
 	priv->gicon=NULL;
 	priv->iconSize=0;
-	priv->isLoaded=FALSE;
-	priv->successfulLoaded=FALSE;
+	priv->loadState=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_NONE;
 	priv->iconTheme=gtk_icon_theme_get_default();
+	priv->missingIconName=g_strdup(XFDASHBOARD_IMAGE_CONTENT_DEFAULT_FALLBACK_ICON_NAME);
+
+	/* Style content */
+	xfdashboard_stylable_invalidate(XFDASHBOARD_STYLABLE(self));
 
 	/* Connect to "attached" signal of ClutterContent to get notified
 	 * when this image is used. We will load image when this image is
@@ -1167,7 +1288,7 @@ void xfdashboard_image_content_init(XfdashboardImageContent *self)
  * In all cases a valid ClutterImage object is returned must be unreffed with
  * g_object_unref().
  */
-ClutterImage* xfdashboard_image_content_new_for_icon_name(const gchar *inIconName, gint inSize)
+ClutterContent* xfdashboard_image_content_new_for_icon_name(const gchar *inIconName, gint inSize)
 {
 	ClutterImage		*image;
 	gchar				*key;
@@ -1195,7 +1316,7 @@ ClutterImage* xfdashboard_image_content_new_for_icon_name(const gchar *inIconNam
 	g_free(key);
 
 	/* Return ClutterImage */
-	return(image);
+	return(CLUTTER_CONTENT(image));
 }
 
 /* Create new instance or use cached one for GIcon object.
@@ -1204,7 +1325,7 @@ ClutterImage* xfdashboard_image_content_new_for_icon_name(const gchar *inIconNam
  * In all cases a valid ClutterImage object is returned must be unreffed with
  * g_object_unref().
  */
-ClutterImage* xfdashboard_image_content_new_for_gicon(GIcon *inIcon, gint inSize)
+ClutterContent* xfdashboard_image_content_new_for_gicon(GIcon *inIcon, gint inSize)
 {
 	ClutterImage		*image;
 	gchar				*key;
@@ -1232,7 +1353,7 @@ ClutterImage* xfdashboard_image_content_new_for_gicon(GIcon *inIcon, gint inSize
 	g_free(key);
 
 	/* Return ClutterImage */
-	return(image);
+	return(CLUTTER_CONTENT(image));
 }
 
 /* Create a new instance for GdkPixbuf object.
@@ -1242,7 +1363,7 @@ ClutterImage* xfdashboard_image_content_new_for_gicon(GIcon *inIcon, gint inSize
  * The return ClutterImage object (if not NULL) must be unreffed with
  * g_object_unref().
  */
-ClutterImage* xfdashboard_image_content_new_for_pixbuf(GdkPixbuf *inPixbuf)
+ClutterContent* xfdashboard_image_content_new_for_pixbuf(GdkPixbuf *inPixbuf)
 {
 	ClutterContent		*image;
 	GError				*error;
@@ -1277,7 +1398,58 @@ ClutterImage* xfdashboard_image_content_new_for_pixbuf(GdkPixbuf *inPixbuf)
 	}
 
 	/* Return ClutterImage */
-	return(CLUTTER_IMAGE(image));
+	return(CLUTTER_CONTENT(image));
+}
+
+/* Get/set icon name to use when requested icon cannot be loaded */
+const gchar* xfdashboard_image_content_get_missing_icon_name(XfdashboardImageContent *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_IMAGE_CONTENT(self), NULL);
+
+	return(self->priv->missingIconName);
+}
+
+void xfdashboard_image_content_set_missing_icon_name(XfdashboardImageContent *self, const gchar *inMissingIconName)
+{
+	XfdashboardImageContentPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_IMAGE_CONTENT(self));
+	g_return_if_fail(inMissingIconName && *inMissingIconName);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(g_strcmp0(priv->missingIconName, inMissingIconName)!=0)
+	{
+		/* Set value */
+		if(priv->missingIconName)
+		{
+			g_free(priv->missingIconName);
+			priv->missingIconName=NULL;
+		}
+
+		if(inMissingIconName) priv->missingIconName=g_strdup(inMissingIconName);
+
+		/* If this image content is a failed one then reload it */
+		if(priv->loadState==XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_LOADED_FAILED)
+		{
+			/* Set state of image to "not-loaded" */
+			priv->loadState=XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_NONE;
+
+			/* Call signal handler for first-time attached image content which
+			 * will set up an empty image first and then tries to load the image.
+			 * It is likely to fail again but then it will show the new missing
+			 * icon instead of the old one.
+			 */
+			_xfdashboard_image_content_on_attached(CLUTTER_CONTENT(self), NULL, NULL);
+		}
+
+		/* Invalidate ourselve to get us redrawn */
+		clutter_content_invalidate(CLUTTER_CONTENT(self));
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardImageContentProperties[PROP_MISSING_ICON_NAME]);
+	}
 }
 
 /* Get size of image as specified when creating this object instance */
@@ -1302,3 +1474,30 @@ void xfdashboard_image_content_get_real_size(XfdashboardImageContent *self, gint
 	if(outWidth) *outWidth=floor(w);
 	if(outHeight) *outHeight=floor(h);
 }
+
+/* Get loading state of image */
+XfdashboardImageContentLoadingState xfdashboard_image_content_get_state(XfdashboardImageContent *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_IMAGE_CONTENT(self), XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_NONE);
+
+	return(self->priv->loadState);
+}
+
+/* Force loading image if not available */
+void xfdashboard_image_content_force_load(XfdashboardImageContent *self)
+{
+	XfdashboardImageContentPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_IMAGE_CONTENT(self));
+
+	priv=self->priv;
+
+	/* If loading state is none then image was not loaded yet and is also
+	 * not being loaded currently. So enforce loading now.
+	 */
+	if(priv->loadState==XFDASHBOARD_IMAGE_CONTENT_LOADING_STATE_NONE)
+	{
+		g_debug("Need to enforce loading '%s'", priv->iconName);
+		_xfdashboard_image_content_on_attached(CLUTTER_CONTENT(self), NULL, NULL);
+	}
+}
