@@ -212,7 +212,7 @@ static void _xfdashboard_live_window_on_icon_changed(XfdashboardLiveWindow *self
 														gpointer inUserData)
 {
 	XfdashboardLiveWindowPrivate	*priv;
-	ClutterImage					*icon;
+	ClutterContent					*icon;
 
 	g_return_if_fail(XFDASHBOARD_IS_LIVE_WINDOW(self));
 	g_return_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW(inWindow));
@@ -224,7 +224,7 @@ static void _xfdashboard_live_window_on_icon_changed(XfdashboardLiveWindow *self
 
 	/* Set new icon in title actor */
 	icon=xfdashboard_image_content_new_for_pixbuf(xfdashboard_window_tracker_window_get_icon(inWindow));
-	xfdashboard_button_set_icon_image(XFDASHBOARD_BUTTON(priv->actorTitle), icon);
+	xfdashboard_button_set_icon_image(XFDASHBOARD_BUTTON(priv->actorTitle), CLUTTER_IMAGE(icon));
 	g_object_unref(icon);
 }
 
@@ -273,6 +273,36 @@ static void _xfdashboard_live_window_on_state_changed(XfdashboardLiveWindow *sel
 		priv->isVisible=isVisible;
 		g_signal_emit(self, XfdashboardLiveWindowSignals[SIGNAL_VISIBILITY_CHANGED], 0);
 	}
+
+	/* Add or remove class depending on 'pinned' window state */
+	if(xfdashboard_window_tracker_window_is_pinned(inWindow))
+	{
+		xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(self), "window-state-pinned");
+	}
+		else
+		{
+			xfdashboard_stylable_remove_class(XFDASHBOARD_STYLABLE(self), "window-state-pinned");
+		}
+
+	/* Add or remove class depending on 'minimized' window state */
+	if(xfdashboard_window_tracker_window_is_minized(inWindow))
+	{
+		xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(self), "window-state-minimized");
+	}
+		else
+		{
+			xfdashboard_stylable_remove_class(XFDASHBOARD_STYLABLE(self), "window-state-minimized");
+		}
+
+	/* Add or remove class depending on 'urgent' window state */
+	if(xfdashboard_window_tracker_window_is_urgent(inWindow))
+	{
+		xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(self), "window-state-urgent");
+	}
+		else
+		{
+			xfdashboard_stylable_remove_class(XFDASHBOARD_STYLABLE(self), "window-state-urgent");
+		}
 }
 
 /* Window's workspace has changed */
