@@ -177,6 +177,7 @@ static void _xfdashboard_window_tracker_window_on_screen_size_changed(Xfdashboar
 	memset(&xEvent, 0, sizeof(xEvent));
 	xEvent.type=ClientMessage;
 	xEvent.xclient.window=wnck_window_get_xid(stageWindow);
+	xEvent.xclient.display=GDK_DISPLAY_XDISPLAY(display);
 	xEvent.xclient.message_type=atomFullscreenMonitors;
 	xEvent.xclient.format=32;
 	xEvent.xclient.data.l[0]=topIndex;
@@ -528,6 +529,15 @@ gboolean xfdashboard_window_tracker_window_is_pinned(XfdashboardWindowTrackerWin
 	return(wnck_window_is_pinned(WNCK_WINDOW(inWindow)));
 }
 
+gboolean xfdashboard_window_tracker_window_is_urgent(XfdashboardWindowTrackerWindow *inWindow)
+{
+	g_return_val_if_fail(WNCK_IS_WINDOW(inWindow), FALSE);
+
+	if(wnck_window_get_state(WNCK_WINDOW(inWindow)) & WNCK_WINDOW_STATE_URGENT) return(TRUE);
+
+	return(FALSE);
+}
+
 /* Get possible actions of window */
 gboolean xfdashboard_window_tracker_window_has_close_action(XfdashboardWindowTrackerWindow *inWindow)
 {
